import { Request, Response, RequestOptions } from "servie/dist/node";
import { APIGatewayEvent as Event, APIGatewayProxyResult as Result, Context } from "aws-lambda";
export { Event, Context, Result };
/**
 * AWS Lambda promise handler.
 */
export declare type Handler = (event: Event, context: Context) => Promise<Result>;
/**
 * Extends `Request` with AWS lambda context.
 */
export interface LambdaRequestOptions extends RequestOptions {
    context: Context;
    event: Event;
}
/**
 * Extends HTTP requests with AWS Lambda context.
 */
export declare class LambdaRequest extends Request {
    context: Context;
    event: Event;
    constructor(input: string | LambdaRequest, options: LambdaRequestOptions);
}
/**
 * Valid AWS lambda server signature.
 */
export declare type App = (req: LambdaRequest, next: () => Promise<Response>) => Response | Promise<Response>;
/**
 * Lambda server options.
 */
export interface Options {
    isBinary?: (res: Response) => boolean;
    logError?: (err: Error) => void;
    production?: boolean;
}
/**
 * Create a server for handling AWS Lambda requests.
 */
export declare function createHandler(app: App, options?: Options): Handler;
