"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_1 = require("servie/dist/node");
const index_1 = require("./index");
describe("servie-lambda", () => {
    const event = {
        path: "/test",
        pathParameters: null,
        httpMethod: "GET",
        body: null,
        resource: "/test",
        headers: {},
        multiValueHeaders: {
            Test: ["a", "b", "c"]
        },
        isBase64Encoded: false,
        queryStringParameters: {},
        multiValueQueryStringParameters: {},
        stageVariables: {},
        requestContext: {
            identity: {
                sourceIp: "127.0.0.1"
            }
        }
    };
    const context = {
        functionName: "",
        functionVersion: "$LATEST",
        memoryLimitInMB: "128"
    };
    it("should support routers", () => __awaiter(this, void 0, void 0, function* () {
        const handler = index_1.createHandler(function () {
            return new node_1.Response("response", {
                status: 200
            });
        });
        const res = yield handler(event, context);
        expect(res).toEqual({
            statusCode: 200,
            body: "response",
            multiValueHeaders: {
                "content-type": ["text/plain"],
                "content-length": ["8"]
            },
            isBase64Encoded: false
        });
    }));
    it("should fall through to 404", () => __awaiter(this, void 0, void 0, function* () {
        const handler = index_1.createHandler((_req, next) => next());
        const res = yield handler(event, context);
        expect(res).toEqual({
            statusCode: 404,
            body: "Cannot GET /test",
            multiValueHeaders: {
                "content-type": ["text/plain"],
                "content-security-policy": ["default-src 'self'"],
                "x-content-type-options": ["nosniff"],
                "content-length": ["16"]
            },
            isBase64Encoded: false
        });
    }));
    it("should support multiple headers of the same key", () => __awaiter(this, void 0, void 0, function* () {
        const handler = index_1.createHandler(() => {
            return new node_1.Response(null, {
                headers: {
                    "Set-Cookie": ["a=a", "b=b", "c=c"]
                }
            });
        });
        const res = yield handler(event, context);
        expect(res).toEqual({
            statusCode: 200,
            body: "",
            multiValueHeaders: {
                "set-cookie": ["a=a", "b=b", "c=c"]
            },
            isBase64Encoded: false
        });
    }));
    it("should log and rewrite errors", () => __awaiter(this, void 0, void 0, function* () {
        const logError = jest.fn();
        const handler = index_1.createHandler(() => Promise.reject(new Error("boom")), {
            logError
        });
        const res = yield handler(event, context);
        expect(res.statusCode).toEqual(500);
        expect(res.isBase64Encoded).toEqual(false);
        expect(res.body).toContain("boom");
        expect(logError).toHaveBeenCalled();
    }));
});
//# sourceMappingURL=index.spec.js.map